index\_calculator.preprocessing
===============================

.. currentmodule:: index_calculator

.. autoclass:: preprocessing


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~preprocessing.__init__
      ~preprocessing.preprocessing
